#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='qz7_hello',
      version='0.1',
      description='qz7 hello.',
      author='Parantapa Bhattacharya',
      author_email='pb@parantapa.net',
      url='https://github.com/parantapa/qz7_hello',
      py_modules=['qz7_hello'],
     )
